Type: Package
Package: ggdibbler
Title: Add Uncertainty to Data Visualisations
Version: 0.6.5
Authors@R: c(
    person("Harriet", "Mason", , "harriet.m.mason@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0009-0007-4568-8215")),
    person("Dianne", "Cook", , "dicook@monash.edu", role = c("aut", "ths"),
           comment = c(ORCID = "0000-0002-3813-7155")),
    person("Sarah", "Goodwin", , "sarah.goodwin@monash.edu", role = c("aut", "ths"),
           comment = c(ORCID = "0000-0001-8894-8282")),
    person("Susan", "VanderPlas", , "susan.vanderplas@unl.edu", role = c("aut", "ths"),
           comment = c(ORCID = "0000-0002-3803-0972"))
  )
Maintainer: Harriet Mason <harriet.m.mason@gmail.com>
Description: A 'ggplot2' extension for visualising uncertainty with the goal
    of signal suppression. Usually, uncertainty visualisation focuses on
    expressing uncertainty as a distribution or probability, whereas
    'ggdibbler' differentiates itself by viewing an uncertainty
    visualisation as an adjustment to an existing graphic that
    incorporates the inherent uncertainty in the estimates.  You provide
    the code for an existing plot, but replace any of the variables with a
    vector of distributions, and it will convert the visualisation into
    it's signal suppression counterpart.
License: GPL-3
URL: https://harriet-mason.github.io/ggdibbler/,
        https://github.com/harriet-mason/ggdibbler
Depends: R (>= 4.1.0)
Imports: distributional, dplyr, ggplot2, rlang, lifecycle, scales,
        tidyr, tibble, cli, sf
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), vdiffr, mgcv, fable,
        urca, gganimate, tidyverse, tidygraph, ggthemes, gifski,
        ggridges, quantreg, ggdist, ggraph, feasts, patchwork
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
BugReports: https://github.com/harriet-mason/ggdibbler/issues
NeedsCompilation: no
Packaged: 2026-05-13 14:11:02 UTC; hmas0003
Author: Harriet Mason [aut, cre] (ORCID:
    <https://orcid.org/0009-0007-4568-8215>),
  Dianne Cook [aut, ths] (ORCID: <https://orcid.org/0000-0002-3813-7155>),
  Sarah Goodwin [aut, ths] (ORCID:
    <https://orcid.org/0000-0001-8894-8282>),
  Susan VanderPlas [aut, ths] (ORCID:
    <https://orcid.org/0000-0002-3803-0972>)
Repository: CRAN
Date/Publication: 2026-05-13 14:50:02 UTC
Built: R 4.6.0; ; 2026-05-13 15:21:45 UTC; unix
