# Generated by roxygen2: do not edit by hand

S3method(ggplot2::scale_type,distribution)
export(PositionDodgeDodge)
export(PositionDodgeIdentity)
export(PositionIdentityDodge)
export(PositionIdentityStack)
export(PositionNest)
export(PositionStackDodge)
export(PositionStackIdentity)
export(PositionSubdivide)
export(StatAlignSample)
export(StatBin2dSample)
export(StatBinSample)
export(StatBindotSample)
export(StatBinhexSample)
export(StatBoxplotSample)
export(StatConnectSample)
export(StatContourFilledSample)
export(StatContourSample)
export(StatCountSample)
export(StatDensity2dFilledSample)
export(StatDensity2dSample)
export(StatDensitySample)
export(StatEcdfSample)
export(StatEllipseSample)
export(StatIdentitySample)
export(StatManualSample)
export(StatQqLineSample)
export(StatQqSample)
export(StatQuantileSample)
export(StatSfSample)
export(StatSmoothSample)
export(StatSumSample)
export(StatSummary2dSample)
export(StatSummaryBinSample)
export(StatSummaryHexSample)
export(StatSummarySample)
export(StatUniqueSample)
export(StatYdensitySample)
export(dibble_to_tibble)
export(geom_abline_sample)
export(geom_area_sample)
export(geom_bar_sample)
export(geom_bin_2d_sample)
export(geom_boxplot_sample)
export(geom_col_sample)
export(geom_contour_filled_sample)
export(geom_contour_sample)
export(geom_count_sample)
export(geom_crossbar_sample)
export(geom_curve_sample)
export(geom_density2d_filled_sample)
export(geom_density2d_sample)
export(geom_density_2d_filled_sample)
export(geom_density_2d_sample)
export(geom_density_sample)
export(geom_dotplot_sample)
export(geom_errorbar_sample)
export(geom_freqpoly_sample)
export(geom_hex_sample)
export(geom_histogram_sample)
export(geom_hline_sample)
export(geom_jitter_sample)
export(geom_label_sample)
export(geom_line_sample)
export(geom_linerange_sample)
export(geom_path_sample)
export(geom_point_sample)
export(geom_pointrange_sample)
export(geom_polygon_sample)
export(geom_qq_line_sample)
export(geom_qq_sample)
export(geom_quantile_sample)
export(geom_raster_sample)
export(geom_rect_sample)
export(geom_ribbon_sample)
export(geom_rug_sample)
export(geom_segment_sample)
export(geom_sf_sample)
export(geom_smooth_sample)
export(geom_spoke_sample)
export(geom_step_sample)
export(geom_text_sample)
export(geom_tile_sample)
export(geom_violin_sample)
export(geom_vline_sample)
export(position_dodge_dodge)
export(position_dodge_identity)
export(position_identity_dodge)
export(position_identity_identity)
export(position_identity_stack)
export(position_nest)
export(position_stack_dodge)
export(position_stack_identity)
export(position_subdivide)
export(sample_expand)
export(scale_x_continuous_distribution)
export(scale_x_discrete_distribution)
export(scale_y_continuous_distribution)
export(scale_y_discrete_distribution)
export(stat_align_sample)
export(stat_bin_2d_sample)
export(stat_bin_hex_sample)
export(stat_bin_sample)
export(stat_boxplot_sample)
export(stat_connect_sample)
export(stat_contour_filled_sample)
export(stat_contour_sample)
export(stat_count_sample)
export(stat_density_2d_filled_sample)
export(stat_density_2d_sample)
export(stat_density_sample)
export(stat_ecdf_sample)
export(stat_ellipse_sample)
export(stat_identity_sample)
export(stat_manual_sample)
export(stat_qq_line_sample)
export(stat_qq_sample)
export(stat_quantile_sample)
export(stat_smooth_sample)
export(stat_sum_sample)
export(stat_summary_2d_sample)
export(stat_summary_bin_sample)
export(stat_summary_hex_sample)
export(stat_summary_sample)
export(stat_unique_sample)
export(stat_ydensity_sample)
importFrom(cli,cli_abort)
importFrom(distributional,generate)
importFrom(distributional,is_distribution)
importFrom(distributional,parameters)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,mutate)
importFrom(ggplot2,GeomAbline)
importFrom(ggplot2,GeomArea)
importFrom(ggplot2,GeomBar)
importFrom(ggplot2,GeomBin2d)
importFrom(ggplot2,GeomBoxplot)
importFrom(ggplot2,GeomCol)
importFrom(ggplot2,GeomContour)
importFrom(ggplot2,GeomContourFilled)
importFrom(ggplot2,GeomCrossbar)
importFrom(ggplot2,GeomCurve)
importFrom(ggplot2,GeomDensity)
importFrom(ggplot2,GeomDensity2d)
importFrom(ggplot2,GeomDotplot)
importFrom(ggplot2,GeomErrorbar)
importFrom(ggplot2,GeomHex)
importFrom(ggplot2,GeomHline)
importFrom(ggplot2,GeomLabel)
importFrom(ggplot2,GeomLine)
importFrom(ggplot2,GeomLinerange)
importFrom(ggplot2,GeomPath)
importFrom(ggplot2,GeomPoint)
importFrom(ggplot2,GeomPointrange)
importFrom(ggplot2,GeomPolygon)
importFrom(ggplot2,GeomQuantile)
importFrom(ggplot2,GeomRaster)
importFrom(ggplot2,GeomRect)
importFrom(ggplot2,GeomRibbon)
importFrom(ggplot2,GeomRug)
importFrom(ggplot2,GeomSegment)
importFrom(ggplot2,GeomSf)
importFrom(ggplot2,GeomSmooth)
importFrom(ggplot2,GeomSpoke)
importFrom(ggplot2,GeomStep)
importFrom(ggplot2,GeomText)
importFrom(ggplot2,GeomTile)
importFrom(ggplot2,GeomViolin)
importFrom(ggplot2,GeomVline)
importFrom(ggplot2,Position)
importFrom(ggplot2,PositionDodge)
importFrom(ggplot2,PositionIdentity)
importFrom(ggplot2,PositionStack)
importFrom(ggplot2,ScaleDiscretePosition)
importFrom(ggplot2,Stat)
importFrom(ggplot2,StatAlign)
importFrom(ggplot2,StatBin)
importFrom(ggplot2,StatBin2d)
importFrom(ggplot2,StatBindot)
importFrom(ggplot2,StatBinhex)
importFrom(ggplot2,StatBoxplot)
importFrom(ggplot2,StatConnect)
importFrom(ggplot2,StatContour)
importFrom(ggplot2,StatContourFilled)
importFrom(ggplot2,StatCount)
importFrom(ggplot2,StatDensity)
importFrom(ggplot2,StatDensity2d)
importFrom(ggplot2,StatEcdf)
importFrom(ggplot2,StatEllipse)
importFrom(ggplot2,StatManual)
importFrom(ggplot2,StatQq)
importFrom(ggplot2,StatQqLine)
importFrom(ggplot2,StatQuantile)
importFrom(ggplot2,StatSf)
importFrom(ggplot2,StatSmooth)
importFrom(ggplot2,StatSum)
importFrom(ggplot2,StatSummary)
importFrom(ggplot2,StatSummary2d)
importFrom(ggplot2,StatSummaryBin)
importFrom(ggplot2,StatSummaryHex)
importFrom(ggplot2,StatUnique)
importFrom(ggplot2,StatYdensity)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_sf)
importFrom(ggplot2,discrete_scale)
importFrom(ggplot2,ggproto)
importFrom(ggplot2,ggproto_parent)
importFrom(ggplot2,layer)
importFrom(ggplot2,layer_sf)
importFrom(ggplot2,make_constructor)
importFrom(ggplot2,position_jitter)
importFrom(ggplot2,scale_type)
importFrom(ggplot2,waiver)
importFrom(lifecycle,deprecate_soft)
importFrom(lifecycle,deprecated)
importFrom(lifecycle,is_present)
importFrom(rlang,arg_match0)
importFrom(rlang,caller_env)
importFrom(rlang,current_call)
importFrom(rlang,exprs)
importFrom(rlang,list2)
importFrom(scales,DiscreteRange)
importFrom(scales,oob_keep)
importFrom(tibble,rowid_to_column)
importFrom(tibble,tibble)
importFrom(tidyr,unnest_longer)
